@@ -9,7 +9,7 @@ class BUIbackend:
     def status(self, query='\n', agent=None):
         raise NotImplementedError("Sorry, the current Backend does not implement this method!")
 
-    def parse_backup_log(self, f, n, c=None, agent=None):
+    def get_backup_logs(self, n, c, forward=False, agent=None):
         raise NotImplementedError("Sorry, the current Backend does not implement this method!")
 
     def get_counters(self, name=None, agent=None):
@@ -30,5 +30,20 @@ class BUIbackend:
     def get_tree(self, name=None, backup=None, root=None, agent=None):
         raise NotImplementedError("Sorry, the current Backend does not implement this method!")
 
+    def restore_files(self, name=None, backup=None, files=None, strip=None, agent=None):
+        raise NotImplementedError("Sorry, the current Backend does not implement this method!")
+
+    def read_conf(self, agent=None):
+        raise NotImplementedError("Sorry, the current Backend does not implement this method!")
+
+    def store_conf(self, data, agent=None):
+        raise NotImplementedError("Sorry, the current Backend does not implement this method!")
+
+    def get_parser_attr(self, attr=None, agent=None):
+        raise NotImplementedError("Sorry, the current Backend does not implement this method!")
+
+class BUIserverException(Exception):
+    pass
+
 class BUIserverException(Exception):
     pass
