@@ -1,7 +1,8 @@
 # -*- coding: utf8 -*-
 import math
+import select
 from zlib import adler32
-from time import gmtime, strftime, time, sleep
+from time import gmtime, strftime, time
 
 from flask import Flask, Response, request, render_template, jsonify, redirect, url_for, abort, flash, send_file
 from flask.ext.login import login_user, login_required, logout_user 
@@ -18,11 +19,43 @@ def load_user(userid):
         return bui.uhandler.user(userid)
     return None
 
+@app.route('/settings', methods=['GET', 'POST'])
+@app.route('/<server>/settings', methods=['GET', 'POST'])
+@login_required
+def settings(server=None):
+    if request.method == 'POST':
+        noti = bui.cli.store_conf(request.form)
+        return jsonify(notif=noti)
+    return render_template('settings.html', settings=True, server=server)
+
+@app.route('/api/server-config')
+@app.route('/api/<server>/server-config')
+@login_required
+def read_conf_srv(server=None):
+    r = bui.cli.read_conf(server)
+    return jsonify(results=r,
+                   boolean=bui.cli.get_parser_attr('boolean'),
+                   string=bui.cli.get_parser_attr('string'),
+                   integer=bui.cli.get_parser_attr('integer'),
+                   multi=bui.cli.get_parser_attr('multi'),
+                   server_doc=bui.cli.get_parser_attr('server_doc'),
+                   suggest=bui.cli.get_parser_attr('values_server'),
+                   placeholders=bui.cli.get_parser_attr('placeholders'),
+                   defaults=bui.cli.get_parser_attr('defaults_server'))
+
+
+"""
+Here is the API
+
+The whole API returns JSON-formated data
+"""
+
 @app.route('/api/restore/<name>/<int:backup>', methods=['POST'])
 @app.route('/api/<server>/restore/<name>/<int:backup>', methods=['POST'])
 @login_required
 def restore(server=None, name=None, backup=None):
     l = request.form.get('list')
+    s = request.form.get('strip')
     resp = None
     if not l or not name or not backup:
         abort(500)
@@ -31,11 +64,11 @@ def restore(server=None, name=None, backup=None):
     else:
         filename = 'restoration_%d_%s_at_%s.zip' % (backup, name, strftime("%Y-%m-%d_%H_%M_%S", gmtime()))
     if not server:
-        archive = bui.cli.restore_files(name, backup, l)
+        archive = bui.cli.restore_files(name, backup, l, s)
         if not archive:
             abort(500)
         try:
-            resp = send_file(archive, as_attachment=True, attachment_filename=filename)
+            resp = send_file(archive, as_attachment=True, attachment_filename=filename, mimetype='application/zip')
             resp.set_cookie('fileDownload', 'true')
         except Exception, e:
             app.logger.error(str(e))
@@ -43,21 +76,20 @@ def restore(server=None, name=None, backup=None):
     else:
         socket = None
         try:
-            socket, length = bui.cli.restore_files(name, backup, l, server)
+            socket, length = bui.cli.restore_files(name, backup, l, s, server)
             app.logger.debug('Need to get %d Bytes : %s', length, socket)
             def stream_file(sock, l):
                 bsize = 1024
-                timeout = 5
                 received = 0
-                tries = 0
                 if l < bsize:
                     bsize = l
-                while received < l and tries < timeout:
+                while received < l:
                     buf = b''
+                    r, _, _ = select.select([sock], [], [], 5)
+                    if not r:
+                        raise Exception ('Socket timed-out')
                     buf += sock.recv(bsize)
                     if not buf:
-                        tries += 1
-                        sleep(0.1)
                         continue
                     received += len(buf)
                     app.logger.debug('%d/%d', received, l)
@@ -68,7 +100,7 @@ def restore(server=None, name=None, backup=None):
             headers.add('Content-Disposition', 'attachment', filename=filename)
             headers['Content-Length'] = length
 
-            resp = Response(stream_file(socket, length), mimetype='application/octet-stream',
+            resp = Response(stream_file(socket, length), mimetype='application/zip',
                             headers=headers, direct_passthrough=True)
             resp.set_cookie('fileDownload', 'true')
             resp.set_etag('flask-%s-%s-%s' % (
@@ -80,13 +112,6 @@ def restore(server=None, name=None, backup=None):
             abort(500)
     return resp
 
-
-"""
-Here is the API
-
-The whole API returns JSON-formated data
-"""
-
 @app.route('/api/running-clients.json')
 @app.route('/api/<server>/running-clients.json')
 @login_required
@@ -140,8 +165,9 @@ def render_live_tpl(server=None, name=None):
 @login_required
 def servers_json():
     r = []
-    for serv in bui.cli.servers:
-        r.append({'name': serv, 'clients': len(bui.cli.servers[serv].get_all_clients(serv)), 'alive': bui.cli.servers[serv].ping()})
+    if hasattr(bui.cli, 'servers'):
+        for serv in bui.cli.servers:
+            r.append({'name': serv, 'clients': len(bui.cli.servers[serv].get_all_clients(serv)), 'alive': bui.cli.servers[serv].ping()})
     return jsonify(results=r)
 
 @app.route('/api/live.json')
@@ -242,11 +268,9 @@ def clients_report_json(server=None):
         client = bui.cli.get_client(c['name'], agent=server)
         if not client:
             continue
-        f = bui.cli.status('c:{0}:b:{1}:f:log.gz\n'.format(c['name'], client[-1]['number']), agent=server)
-        cl.append( { 'name': c['name'], 'stats': bui.cli.parse_backup_log(f, client[-1]['number'], agent=server) } )
+        cl.append( { 'name': c['name'], 'stats': bui.cli.get_backup_logs(client[-1]['number'], c['name'], agent=server) } )
         for b in client:
-            f = bui.cli.status('c:{0}:b:{1}:f:log.gz\n'.format(c['name'], b['number']), agent=server)
-            ba.append(bui.cli.parse_backup_log(f, b['number'], c['name'], agent=server))
+            ba.append(bui.cli.get_backup_logs(b['number'], c['name'], True, agent=server))
     j.append( { 'clients': cl, 'backups': sorted(ba, key=lambda k: k['end']) } )
     return jsonify(results=j)
 
@@ -267,11 +291,10 @@ def client_stat_json(server=None, name=None, backup=None):
         return jsonify(notif=err)
     if backup:
         try:
-            f = bui.cli.status('c:{0}:b:{1}:f:log.gz\n'.format(name, backup), agent=server)
+            j = bui.cli.get_backup_logs(backup, name, agent=server)
         except BUIserverException, e:
             err = [[2, str(e)]]
             return jsonify(notif=err)
-        j = bui.cli.parse_backup_log(f, backup, agent=server)
     else:
         try:
             cl = bui.cli.get_client(name, agent=server)
@@ -279,8 +302,7 @@ def client_stat_json(server=None, name=None, backup=None):
             err = [[2, str(e)]]
             return jsonify(notif=err)
         for c in cl:
-            f =  bui.cli.status('c:{0}:b:{1}:f:log.gz\n'.format(name, c['number']), agent=server)
-            j.append(bui.cli.parse_backup_log(f, c['number'], agent=server))
+            j.append(bui.cli.get_backup_logs(c['number'], name, agent=server))
     return jsonify(results=j)
 
 @app.route('/api/client.json/<name>')
@@ -397,7 +419,7 @@ def client_report(server=None, name=None):
         server = request.args.get('server')
     l = bui.cli.get_client(name, agent=server)
     if len(l) == 1:
-        return redirect(url_for('backup_report', name=name, backup=l[0]['number']), server=server)
+        return redirect(url_for('backup_report', name=name, backup=l[0]['number'], server=server))
     return render_template('client-report.html', client=True, report=True, cname=name, server=server)
 
 @app.route('/clients-report')
