@@ -4,7 +4,8 @@ var pad = function(num, size) {
 	return s.substr(s.length-size);
 };
 
-var notif = function(type, message) {
+var notif = function(type, message, timeout) {
+	timeout = (typeof timeout === "undefined") ? 5000 : timeout;
 	var t = '';
 	switch(type) {
 		case 0:
@@ -26,11 +27,11 @@ var notif = function(type, message) {
 			break;
 	}
 	e = $('<div class="alert alert-dismissable alert-'+t+'">'+
-			'<button type="button" class="close" data-dismiss="alert">×</button>'+
+			'<button type="button" class="close" data-dismiss="alert">&times;</button>'+
 			i+message+
 		  '</div>');
 	$('#bui-notifications').append(e).show();
-	e.animate({opacity:1}, 5000, 'linear', function() { e.animate({opacity:0}, 2000, 'linear', function() {e.remove(); }); });
+	e.animate({opacity:1}, timeout, 'linear', function() { e.animate({opacity:0}, 2000, 'linear', function() {e.remove(); }); });
 };
 
 {% if not login -%}
@@ -60,7 +61,7 @@ var _clients_bh = new Bloodhound({
 	queryTokenizer: Bloodhound.tokenizers.whitespace,
 	limit: 10,
 	prefetch: {
-		url: '{{ url_for("clients_json", server=server) }}',
+		url: '{{ url_for("clients_json") }}',
 		filter: function(list) {
 			if (list.results) {
 				return list.results;
@@ -159,6 +160,10 @@ $('#input-client').typeahead({
 {% include "js/live-monitor.js" %}
 {% endif -%}
 
+{% if settings -%}
+{% include "js/settings.js" %}
+{% endif -%}
+
 var _async_ajax = function(b) {
 	$.ajaxSetup({
 		async: b
@@ -182,11 +187,11 @@ $(function() {
 	$('li.detail').hover(
 		// mouse in
 		function() {
-			$(this).find('.dtl').removeClass('hidden-md hidden-lg');
+			$(this).find('.dtl').animate({width: 'toggle'});
 		},
 		// mouse out
 		function() {
-			$(this).find('.dtl').addClass('hidden-md hidden-lg');
+			$(this).find('.dtl').animate({width: 'toggle'});
 		}
 	);
 
